@@ -126,46 +126,6 @@ class ModelParser:
             k_model, self._should_transform_inputs_and_outputs, self.custom_layers)
 
         model_schema = json.loads(converted_k_model.to_json())
-        model_schema = replace_dots_in_model_schema(model_schema)
 
         return model_schema, converted_k_model
 
-
-def replace_dots_for_tf_ops_inbound_nodes(layer, dot_input_names):
-    inbound_nodes_to_enumerate = KerasJsonModelImport.prepare_inbound_nodes(layer['inbound_nodes'][0])
-    if len(inbound_nodes_to_enumerate) == 1:
-        if layer['inbound_nodes'][0][0] in dot_input_names:
-            layer['inbound_nodes'][0][0] = layer['inbound_nodes'][0][0].replace(".", "_")
-    elif len(inbound_nodes_to_enumerate) == 2:
-        if layer['inbound_nodes'][0][0] in dot_input_names:
-            layer['inbound_nodes'][0][0] = layer['inbound_nodes'][0][0].replace(".", "_")
-        try:
-            if layer['inbound_nodes'][0][-1]['y'][0] in dot_input_names:
-                layer['inbound_nodes'][0][0] = layer['inbound_nodes'][0][0].replace(".", "_")
-        except KeyError:
-            if layer['inbound_nodes'][0][-1]['b'][0] in dot_input_names:
-                layer['inbound_nodes'][0][0] = layer['inbound_nodes'][0][0].replace(".", "_")
-    else:
-        raise Exception('unsupported inbound_nodes')
-
-
-def replace_dots_in_model_schema(model_schema: dict) -> dict:
-    dot_input_names = set()
-    for inp_layer in model_schema["config"]["input_layers"]:
-        if "." in inp_layer[0]:
-            dot_input_names.add(inp_layer[0])
-            inp_layer[0] = inp_layer[0].replace(".", "_")
-    for layer in model_schema["config"]["layers"]:
-        if layer["name"] in dot_input_names:
-            layer["name"] = layer["name"].replace(".", "_")
-            layer["config"]["name"] = layer["config"]["name"].replace(".", "_")
-
-        if layer["inbound_nodes"] and not isinstance(layer["inbound_nodes"][0][0], list):
-            replace_dots_for_tf_ops_inbound_nodes(layer, dot_input_names)
-            continue
-        for inbound_nodes in layer["inbound_nodes"]:
-            for inbound_node in inbound_nodes:
-                if inbound_node[0] in dot_input_names:
-                    inbound_node[0] = inbound_node[0].replace(".", "_")
-
-    return model_schema
